@@ -13,6 +13,7 @@ mod csharp;
 mod css;
 mod elixir;
 mod go;
+mod haskell;
 mod html;
 mod json;
 mod kotlin;
@@ -109,6 +110,10 @@ impl_lang_expando!(Elixir, language_elixir, 'µ');
 // we can use any Unicode code point categorized as "Letter"
 // https://go.dev/ref/spec#letter
 impl_lang_expando!(Go, language_go, 'µ');
+// GHC supports Unicode syntax per
+// https://ghc.gitlab.haskell.org/ghc/doc/users_guide/exts/unicode_syntax.html
+// and the tree-sitter-haskell grammar parses it too.
+impl_lang_expando!(Haskell, language_haskell, 'µ');
 // tree-sitter-html uses locale dependent iswalnum for tagName
 // https://github.com/tree-sitter/tree-sitter-html/blob/b5d9758e22b4d3d25704b72526670759a9e4d195/src/scanner.c#L194
 impl_lang_expando!(Html, language_html, 'z');
@@ -152,6 +157,7 @@ pub enum SupportLang {
   Dart,
   Go,
   Elixir,
+  Haskell,
   Html,
   Java,
   JavaScript,
@@ -172,8 +178,8 @@ impl SupportLang {
   pub const fn all_langs() -> &'static [SupportLang] {
     use SupportLang::*;
     &[
-      Bash, C, Cpp, CSharp, Css, Dart, Elixir, Go, Html, Java, JavaScript, Json, Kotlin, Lua, Php,
-      Python, Ruby, Rust, Scala, Swift, Tsx, TypeScript,
+      Bash, C, Cpp, CSharp, Css, Dart, Elixir, Go, Haskell, Html, Java, JavaScript, Json, Kotlin,
+      Lua, Php, Python, Ruby, Rust, Scala, Swift, Tsx, TypeScript,
     ]
   }
 
@@ -225,6 +231,7 @@ const fn alias(lang: &SupportLang) -> &[&str] {
     Dart => &["dart"],
     Elixir => &["ex", "elixir"],
     Go => &["go", "golang"],
+    Haskell => &["hs", "haskell"],
     Html => &["html"],
     Java => &["java"],
     JavaScript => &["javascript", "js", "jsx"],
@@ -269,6 +276,7 @@ macro_rules! execute_lang_method {
       S::Dart => Dart.$method($($pname,)*),
       S::Elixir => Elixir.$method($($pname,)*),
       S::Go => Go.$method($($pname,)*),
+      S::Haskell => Haskell.$method($($pname,)*),
       S::Html => Html.$method($($pname,)*),
       S::Java => Java.$method($($pname,)*),
       S::JavaScript => JavaScript.$method($($pname,)*),
@@ -324,6 +332,7 @@ fn extensions(lang: &SupportLang) -> &[&str] {
     Dart => &["dart"],
     Elixir => &["ex", "exs"],
     Go => &["go"],
+    Haskell => &["hs"],
     Html => &["html", "htm", "xhtml"],
     Java => &["java"],
     JavaScript => &["cjs", "js", "mjs", "jsx"],
