@@ -1,7 +1,7 @@
 from __future__ import annotations
 
 from typing import List, TypedDict,  Literal, Dict, Union, Mapping
-from .ast_grep_py import SgNode, SgRoot, Pos, Range
+from .ast_grep_py import SgNode, SgRoot, Pos, Range, Edit
 
 class Pattern(TypedDict):
     selector: str
@@ -55,4 +55,5 @@ __all__ = [
     "SgRoot",
     "Pos",
     "Range",
+    "Edit",
 ]
\ No newline at end of file
