@@ -38,4 +38,15 @@ def test_change_unicode():
     nodes = root.find_all(kind="identifier")
     edits = [node.replace('114514') for node in nodes]
     s = root.commit_edits(edits)
-    assert s == "114514 = 114514(114514)"
\ No newline at end of file
+    assert s == "114514 = 114514(114514)"
+
+def test_modified_fix():
+    sg = SgRoot('いいよ = log(514)', "javascript")
+    root = sg.root()
+    node = root.find(kind="number")
+    assert node
+    edit = node.replace('こいよ')
+    edit.position -= 1
+    edit.deleted_length += 2
+    s = root.commit_edits([edit])
+    assert s == "いいよ = logこいよ"
\ No newline at end of file
